@@ -16,7 +16,8 @@ module Vagrant
 
         # Go over each VM and provision!
         @logger.debug("'provision' each target VM...")
-        with_target_vms(argv[0]) do |vm|
+        with_target_vms(argv) do |vm|
+          
           if vm.created?
             if vm.state == :running
               @logger.info("Provisioning: #{vm.name}")
@@ -30,7 +31,10 @@ module Vagrant
             vm.ui.info I18n.t("vagrant.commands.common.vm_not_created")
           end
         end
-      end
+
+        # Success, exit status 0
+        0
+       end
     end
   end
 end
