@@ -33,6 +33,14 @@ module Vagrant
           vm.channel.sudo("/etc/init.d/net.eth#{network[:interface]} start")
         end
       end
+
+      def change_host_name(name)
+        if !vm.channel.test("sudo hostname --fqdn | grep '#{name}'")
+          vm.channel.sudo("echo 'hostname=#{name.split('.')[0]}' > /etc/conf.d/hostname")
+          vm.channel.sudo("sed -i 's@^\\(127[.]0[.]1[.]1[[:space:]]\\+\\)@\\1#{name} #{name.split('.')[0]} @' /etc/hosts")
+          vm.channel.sudo("hostname #{name.split('.')[0]}")
+        end
+      end
     end
   end
 end
