@@ -14,7 +14,7 @@ module Vagrant
           platform.include?("darwin9")
         end
 
-        [:darwin, :bsd, :freebsd, :linux].each do |type|
+        [:darwin, :bsd, :freebsd, :linux, :solaris].each do |type|
           define_method("#{type}?") do
             platform.include?(type.to_s)
           end
