@@ -64,9 +64,13 @@ module Vagrant
         # Make sure the stdin does not buffer
         process.io.stdin.sync = true
 
-        # Close the writer pipes, since we're just reading
-        stdout_writer.close
-        stderr_writer.close
+        if RUBY_PLATFORM != "java"
+          # On Java, we have to close after. See down the method...
+          # Otherwise, we close the writers right here, since we're
+          # not on the writing side.
+          stdout_writer.close
+          stderr_writer.close
+        end
 
         # Create a dictionary to store all the output we see.
         io_data = { :stdout => "", :stderr => "" }
@@ -140,6 +144,13 @@ module Vagrant
           yield io_name, extra_data if block_given?
         end
 
+        if RUBY_PLATFORM == "java"
+          # On JRuby, we need to close the writers after the process,
+          # for some reason. See GH-711.
+          stdout_writer.close
+          stderr_writer.close
+        end
+
         # Return an exit status container
         return Result.new(process.exit_code, io_data[:stdout], io_data[:stderr])
       end
@@ -160,6 +171,15 @@ module Vagrant
               # Windows doesn't support non-blocking reads on
               # file descriptors or pipes so we have to get
               # a bit more creative.
+
+              # Check if data is actually ready on this IO device.
+              # We have to do this since `readpartial` will actually block
+              # until data is available, which can cause blocking forever
+              # in some cases.
+              results = IO.select([io], nil, nil, 1)
+              break if !results || results[0].empty?
+
+              # Read!
               data << io.readpartial(READ_CHUNK_SIZE)
             else
               # Do a simple non-blocking read on the IO object
