@@ -49,11 +49,11 @@ module Vagrant
       @logger.info("Loading guest: #{guest}")
 
       if guest.is_a?(Class)
-        raise Errors::VMGuestError, :_key => :invalid_class, :system => guest.to_s if !(guest <= Guest::Base)
+        raise Errors::VMGuestError, :_key => :invalid_class, :guest => guest.to_s if !(guest <= Guest::Base)
         @guest = guest.new(self)
       elsif guest.is_a?(Symbol)
         guest_klass = Vagrant.guests.get(guest)
-        raise Errors::VMGuestError, :_key => :unknown_type, :system => guest.to_s if !guest_klass
+        raise Errors::VMGuestError, :_key => :unknown_type, :guest => guest.to_s if !guest_klass
         @guest = guest_klass.new(self)
       else
         raise Errors::VMGuestError, :unspecified
